@@ -150,8 +150,7 @@ def get_annotation_args(annotation: Any, module: str, class_name: str) -> tuple[
         return annotation.__parameters__  # type: ignore[no-any-return]
     result = getattr(annotation, "__args__", ())
     # 3.10 and earlier Tuple[()] returns ((), ) instead of () the tuple does
-    result = () if len(result) == 1 and result[0] == () else result  # type: ignore[misc]
-    return result
+    return () if len(result) == 1 and result[0] == () else result  # type: ignore[misc]
 
 
 def format_internal_tuple(t: tuple[Any, ...], config: Config) -> str:
@@ -405,29 +404,32 @@ _TYPE_GUARD_IMPORTS_RESOLVED = set()
 _TYPE_GUARD_IMPORTS_RESOLVED_GLOBALS_ID = set()
 
 
-def _resolve_type_guarded_imports(autodoc_mock_imports: list[str], obj: Any) -> None:
-    if (hasattr(obj, "__module__") and obj.__module__ not in _TYPE_GUARD_IMPORTS_RESOLVED) or (
-        hasattr(obj, "__globals__") and id(obj.__globals__) not in _TYPE_GUARD_IMPORTS_RESOLVED_GLOBALS_ID
-    ):
-        _TYPE_GUARD_IMPORTS_RESOLVED.add(obj.__module__)
-        if obj.__module__ not in sys.builtin_module_names:
-            if hasattr(obj, "__globals__"):
-                _TYPE_GUARD_IMPORTS_RESOLVED_GLOBALS_ID.add(id(obj.__globals__))
+def _resolve_type_guarded_imports(autodoc_mock_imports: list[str], obj: Any) -> None:  # noqa: C901
+    if hasattr(obj, "__module__") and obj.__module__ in _TYPE_GUARD_IMPORTS_RESOLVED:
+        return  # already processed module
+    if not hasattr(obj, "__globals__"):  # classes with __slots__ do not have this
+        return  # if lacks globals nothing we can do
+    if id(obj.__globals__) in _TYPE_GUARD_IMPORTS_RESOLVED_GLOBALS_ID:
+        return  # already processed object
+    _TYPE_GUARD_IMPORTS_RESOLVED.add(obj.__module__)
+    if obj.__module__ not in sys.builtin_module_names:
+        if hasattr(obj, "__globals__"):
+            _TYPE_GUARD_IMPORTS_RESOLVED_GLOBALS_ID.add(id(obj.__globals__))
 
-            module = inspect.getmodule(obj)
-            if module:
-                try:
-                    module_code = inspect.getsource(module)
-                except (TypeError, OSError):
-                    ...  # no source code => no type guards
-                else:
-                    for _, part in _TYPE_GUARD_IMPORT_RE.findall(module_code):
-                        guarded_code = textwrap.dedent(part)
-                        try:
-                            with mock(autodoc_mock_imports):
-                                exec(guarded_code, obj.__globals__)  # noqa: S102
-                        except Exception as exc:  # noqa: BLE001
-                            _LOGGER.warning(f"Failed guarded type import with {exc!r}")
+        module = inspect.getmodule(obj)
+        if module:
+            try:
+                module_code = inspect.getsource(module)
+            except (TypeError, OSError):
+                ...  # no source code => no type guards
+            else:
+                for _, part in _TYPE_GUARD_IMPORT_RE.findall(module_code):
+                    guarded_code = textwrap.dedent(part)
+                    try:
+                        with mock(autodoc_mock_imports):
+                            exec(guarded_code, obj.__globals__)  # noqa: S102
+                    except Exception as exc:  # noqa: BLE001
+                        _LOGGER.warning(f"Failed guarded type import with {exc!r}")
 
 
 def _get_type_hint(autodoc_mock_imports: list[str], name: str, obj: Any) -> dict[str, Any]:
