@@ -6,11 +6,12 @@ from builtins import ValueError  # handle does not have __module__
 from functools import cmp_to_key  # has __module__ but cannot get module as is builtin
 from typing import TYPE_CHECKING
 
+from demo_typing_guard_dummy import AnotherClass
+
 if TYPE_CHECKING:
     from decimal import Decimal
     from typing import Sequence
 
-    from demo_typing_guard_dummy import AnotherClass  # module contains mocked import # noqa: F401
 
 if typing.TYPE_CHECKING:
     from typing import AnyStr
@@ -34,14 +35,27 @@ def a(f: Decimal, s: AnyStr) -> Sequence[AnyStr | Decimal]:
 class SomeClass:
     """This class do something."""
 
+    def create(self, item: Decimal) -> None:
+        """
+        Create something.
+
+        :param item: the item in question
+        """
+
     if TYPE_CHECKING:  # Classes doesn't have `__globals__` attribute
 
-        def __getattr__(self, item: str):  # noqa: ANN204
-            """This method do something."""
+        def guarded(self, item: Decimal) -> None:
+            """
+            Guarded method.
+
+            :param item: some item
+            """
 
 
 __all__ = [
     "a",
     "ValueError",
     "cmp_to_key",
+    "SomeClass",
+    "AnotherClass",
 ]
