@@ -4,4 +4,4 @@ from viktor import AI  # module part of autodoc_mock_imports # noqa: F401
 
 
 class AnotherClass:
-    ...
+    """Another class is here"""
